import 'package:flutter/material.dart';
import 'package:flutter/widgets.dart';
import 'package:layout_grid/layout_grid.dart';

class FeaturesPage extends StatelessWidget {
  @override
  Widget build(BuildContext context) {
    return Layout(
      child: Scaffold(
        appBar: AppBar(
          // Here we take the value from the MyHomePage object that was created by
          // the App.build method, and use it to set our appbar title.
          title: Text('Features'),
        ),
        body: Scrollbar(
          child: Container(
            child: CustomScrollView(
              slivers: [
                SliverPadding(
                  padding: EdgeInsets.symmetric(horizontal: 20),
                  sliver: SliverLayoutGrid(
                    delegate: SliverChildListDelegate([
                      Cell(
                        snap: 12,
                        extent: 52,
                        child: Container(
                          padding: EdgeInsets.only(top: 32),
                          child: Text('Defaut: Cells with extent'),
                        ),
                      ),
                      for (int index in List.generate(12, (i) => i))
                        Cell(
                          snap: 1,
                          extent: 100,
                          child: Card(
                            margin: EdgeInsets.all(0),
                            child: Center(
                              child: Text('Cell $index'),
                            ),
                          ),
                        ),
                      Cell(
                        snap: 12,
                        extent: 52,
                        child: Container(
                          padding: EdgeInsets.only(top: 32),
                          child: Text('Cells with aspect ratio'),
                        ),
                      ),
                      for (int index in List.generate(12, (i) => i))
                        Cell.aspectRatio(
                          snap: 1,
                          child: Card(
                            margin: EdgeInsets.all(0),
                            child: Center(
                              child: Text('Cell $index'),
                            ),
                          ),
                        ),
                      Cell.fit(snap: 12, child: Divider()),
                      Cell(
                        snap: 12,
                        extent: 52,
                        child: Container(
                          padding: EdgeInsets.only(top: 32),
                          child: Text('Fit Cells'),
                        ),
                      ),
                      for (int index in List.generate(12, (i) => i))
                        Cell.fit(
                          snap: 1,
                          child: Card(
                            margin: EdgeInsets.all(0),
                            child: Center(
                              child: Padding(
                                padding: EdgeInsets.all(12),
                                child: Text('Fitted Cell' +
                                    ('.\n' * index) +
                                    ' $index'),
                              ),
                            ),
                          ),
                        ),
                    ]),
                  ),
                ),
                SliverToBoxAdapter(child: Divider()),
                SliverPadding(
                  padding: EdgeInsets.symmetric(horizontal: 20),
                  sliver: SliverLayoutGrid(
                    delegate: SliverChildListDelegate([
                      Cell(
                        snap: 12,
                        extent: 52,
                        child: Container(
                          padding: EdgeInsets.only(top: 32),
                          child: Text('Problems with fit cells'),
                        ),
                      ),
                      for (int index in List.generate(12, (i) => i))
                        Cell.fit(
                          snap: 1,
                          child: Card(
                            margin: EdgeInsets.all(0),
                            child: Center(
                              child: Padding(
                                padding: EdgeInsets.all(12),
                                child: Text(
                                  'Cell $index' +
                                      (index == 2
                                          ? ' -  Super long text cell'
                                          : ''),
                                  textAlign: TextAlign.center,
                                ),
                              ),
                            ),
                          ),
                        ),
                    ]),
                  ),
                ),
                SliverPadding(
                  padding: EdgeInsets.symmetric(horizontal: 20),
                  sliver: SliverLayoutGrid(
                    delegate: SliverChildListDelegate([
                      Cell(
                        snap: 12,
                        extent: 52,
                        child: Container(
                          padding: EdgeInsets.only(top: 32),
                          child: Text('Intrinsic cells'),
                        ),
                      ),
                      for (int index in List.generate(8, (i) => i))
                        IntrinsicCell(
                          snap: 1,
                          child: Card(
                            margin: EdgeInsets.all(0),
                            child: Center(
                              child: Padding(
                                padding: EdgeInsets.all(12),
                                child: Text(
                                  'Cell $index' +
                                      (index == 2
                                          ? ' -  Super long text cell'
                                          : ''),
                                  textAlign: TextAlign.center,
                                ),
                              ),
                            ),
                          ),
                        ),
                    ]),
                  ),
                ),
                SliverPadding(
                  padding: EdgeInsets.symmetric(horizontal: 20),
                  sliver: SliverLayoutGrid(
                    delegate: SliverChildListDelegate([
                      Cell(
                        snap: 12,
                        extent: 52,
                        child: Container(
                          padding: EdgeInsets.only(top: 32),
                          child: Text('Cell with offset'),
                        ),
                      ),
                      for (int index in List.generate(4, (i) => i))
                        Cell.aspectRatio(
                          snap: 1,
                          aspectRatio: 1,
                          offset: index == 2 ? 1 : 0,
                          child: Card(
                            margin: EdgeInsets.all(0),
                            child: Center(
                              child: Padding(
                                padding: EdgeInsets.all(12),
                                child: Text(
                                  'Cell $index' +
                                      (index == 2 ? '\n+\nOffset' : ''),
                                  textAlign: TextAlign.center,
                                ),
                              ),
                            ),
                          ),
                        ),
                    ]),
                  ),
                ),
                SliverToBoxAdapter(child: Divider()),
                SliverPadding(
                  padding: EdgeInsets.symmetric(horizontal: 20),
                  sliver: SliverLayoutGrid(
                    gridDelegate:
                        SliverLayoutGridDelegateWithFixedCrossAxisCount(
                      crossAxisCount: 4,
                      mainAxisSpacing: 12,
                      crossAxisSpacing: 12,
                      masonry: true,
                    ),
                    delegate: SliverChildListDelegate([
                      Cell(
                        snap: 12,
                        extent: 52,
                        child: Container(
                          padding: EdgeInsets.only(top: 32),
                          child: Text(
                              'Mansonry layout vs Normal layout vs Intrinsic Extent Layout'),
                        ),
                      ),
                      for (int index in List.generate(8, (i) => i))
                        Cell(
                          extent: (6 - (index > 3 ? index - 3 : index)) * 30.0,
                          snap: 1,
                          child: Card(
                            margin: EdgeInsets.all(0),
                            child: Center(
                              child: Padding(
                                padding: EdgeInsets.all(12),
                                child: Text(
                                  'Cell $index',
                                  textAlign: TextAlign.center,
                                ),
                              ),
                            ),
                          ),
                        ),
                    ]),
                  ),
                ),
                SliverToBoxAdapter(
                  child: Divider(),
                ),
                SliverPadding(
                  padding: EdgeInsets.symmetric(horizontal: 20),
                  sliver: SliverLayoutGrid(
                    gridDelegate:
                        SliverLayoutGridDelegateWithFixedCrossAxisCount(
                      crossAxisCount: 4,
                      mainAxisSpacing: 12,
                      crossAxisSpacing: 12,
                    ),
                    delegate: SliverChildListDelegate([
                      for (int index in List.generate(8, (i) => i))
                        Cell(
                          extent: (6 - (index > 3 ? index - 3 : index)) * 30.0,
                          snap: 1,
                          child: Card(
                            margin: EdgeInsets.all(0),
                            child: Center(
                              child: Padding(
                                padding: EdgeInsets.all(12),
                                child: Text(
                                  'Cell $index',
                                  textAlign: TextAlign.center,
                                ),
                              ),
                            ),
                          ),
                        ),
                    ]),
                  ),
                ),
                SliverToBoxAdapter(
                  child: Divider(),
                ),
                SliverPadding(
                  padding: EdgeInsets.symmetric(horizontal: 20),
                  sliver: SliverLayoutGrid(
                    gridDelegate:
                        SliverLayoutGridDelegateWithFixedCrossAxisCount(
                      crossAxisCount: 4,
                      mainAxisSpacing: 12,
                      crossAxisSpacing: 12,
                    ),
                    delegate: SliverChildListDelegate([
                      for (int index in List.generate(8, (i) => i))
                        IntrinsicCell(
                          snap: 1,
                          child: Container(
                            height:
                                (6 - (index > 3 ? index - 3 : index)) * 30.0,
                            child: Card(
                              margin: EdgeInsets.all(0),
                              child: Center(
                                child: Padding(
                                  padding: EdgeInsets.all(12),
                                  child: Text(
                                    'Cell $index',
                                    textAlign: TextAlign.center,
                                  ),
                                ),
                              ),
                            ),
                          ),
                        ),
                    ]),
                  ),
                ),
              ],
            ),
          ),
        ),
        floatingActionButton: FloatingActionButton(
          onPressed: () {},
          tooltip: 'Increment',
          child: Icon(Icons.add),
        ), // This trailing comma makes auto-formatting nicer for build methods.
      ),
    );
  }
}
