import 'dart:typed_data';

import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:flutter/rendering.dart';
import 'package:flutter_blurhash/flutter_blurhash.dart';
import 'package:layout_grid/layout_grid.dart';

import 'cupertino_photos.dart';

class GridPage extends StatelessWidget {
  @override
  Widget build(BuildContext context) {
    return CupertinoPageScaffold(
      child: Scaffold(
        backgroundColor: Colors.white,
        extendBody: true,
        bottomNavigationBar: CupertinoTabBar(
          items: [
            BottomNavigationBarItem(
              icon: Icon(
                Icons.photo_library,
                size: 24,
              ),
              label: 'Library',
            ),
            BottomNavigationBarItem(
              icon: Icon(
                Icons.map,
                size: 24,
              ),
              label: 'For you',
            ),
            BottomNavigationBarItem(
              icon: Icon(
                Icons.photo_album,
                size: 24,
              ),
              label: 'Search',
            ),
            BottomNavigationBarItem(
              icon: Icon(
                Icons.search,
                size: 24,
              ),
              label: 'Search',
            ),
          ],
        ),
        body: Scrollbar(
          child: UnsplashPhotoBuilder(
            builder: (list, requestIfNeeded) => CustomScrollView(
              primary: true,
              slivers: [
                SliverPadding(
                  padding: EdgeInsets.all(20),
                  sliver: SliverLayoutGrid(
                    gridDelegate:
                        SliverLayoutGridDelegateWithFixedCrossAxisCount(
                      crossAxisCount: context.layout
                          .value(xs: 2, sm: 3, md: 4, lg: 6, xl: 12),
                      crossAxisSpacing: 16,
                      mainAxisSpacing: 16,
                      masonry: true,
                    ),
                    delegate: SliverChildBuilderDelegate((c, i) {
                      requestIfNeeded(i + 16);
                      final image = list.length > i ? list[i] : null;
                      return Cell.aspectRatio(
                        key: ValueKey('Cell $i'),
                        snap: 1,
                        aspectRatio: image != null
                            ? image.getHeight() / image.getWidth()
                            : 1,
                        child: Container(
                          decoration: BoxDecoration(
                            borderRadius: BorderRadius.circular(12),
                          ),
                          clipBehavior: Clip.antiAlias,
                          constraints: BoxConstraints(minHeight: 100),
                          child: image == null
                              ? null
                              : Stack(
                                  children: [
                                    if (image.blurHash != null)
                                      BlurHash(hash: image.blurHash),
                                    FadeInImage.memoryNetwork(
                                      fadeInDuration:
                                          Duration(milliseconds: 400),
                                      placeholder: kTransparentImage,
                                      image: image.getRegularUrl(),
                                      fit: BoxFit.cover,
                                    ),
                                  ],
                                ),
                        ),
                      );
                    }),
                  ),
                ),
              ],
            ),
          ),
        ),
      ),
    );
  }
}

//https://github.com/brianegan/transparent_image
final Uint8List kTransparentImage = new Uint8List.fromList(<int>[
  0x89,
  0x50,
  0x4E,
  0x47,
  0x0D,
  0x0A,
  0x1A,
  0x0A,
  0x00,
  0x00,
  0x00,
  0x0D,
  0x49,
  0x48,
  0x44,
  0x52,
  0x00,
  0x00,
  0x00,
  0x01,
  0x00,
  0x00,
  0x00,
  0x01,
  0x08,
  0x06,
  0x00,
  0x00,
  0x00,
  0x1F,
  0x15,
  0xC4,
  0x89,
  0x00,
  0x00,
  0x00,
  0x0A,
  0x49,
  0x44,
  0x41,
  0x54,
  0x78,
  0x9C,
  0x63,
  0x00,
  0x01,
  0x00,
  0x00,
  0x05,
  0x00,
  0x01,
  0x0D,
  0x0A,
  0x2D,
  0xB4,
  0x00,
  0x00,
  0x00,
  0x00,
  0x49,
  0x45,
  0x4E,
  0x44,
  0xAE,
]);
