import 'package:flutter/material.dart';
import 'package:flutter_test/flutter_test.dart';
import 'package:layout_grid/layout_grid.dart';

import 'layout_grid_test.dart';

void main() {
  testWidgets('Default cell has 4 columns and fit',
      (WidgetTester tester) async {
    final size = 60.0;
    await tester.pumpWidget(RootWidget(
      width: 12 * size, // 12 col x 60 width
      child: LayoutGrid(
        children: [
          //Row 1
          Cell.fit(
            snap: 4,
            key: ValueKey('Cell'),
            child: Container(height: size),
          ),
        ],
      ),
    ));
    final cellFinder = find.byKey(ValueKey('Cell'));
    final rect = tester.getRect(cellFinder);

    expect(rect.top, equals(0));
    expect(rect.left, equals(0));
    expect(rect.right, equals(size * 4));
    expect(rect.bottom, equals(size));
  });

  testWidgets('Cell with custom columns', (WidgetTester tester) async {
    await tester.pumpWidget(
      RootWidget(
        width: 720, // 12 col x 60 width
        child: LayoutGrid(
          children: [
            Cell.fit(
              snap: 12,
              key: ValueKey('Cell'),
              child: Container(
                height: 60,
              ),
            )
          ],
        ),
      ),
    );
    final cellFinder = find.byKey(ValueKey('Cell'));

    expect(
      tester.getRect(cellFinder),
      Rect.fromLTWH(0.0, 0.0, 720, 60.0),
    );
  });

  testWidgets('Cell with fixed extent', (WidgetTester tester) async {
    await tester.pumpWidget(
      RootWidget(
        width: 720, // 12 col x 60 width
        child: LayoutGrid(
          children: [
            Cell(
              snap: 12,
              key: ValueKey('Cell'),
              extent: 60,
              child: Container(),
            )
          ],
        ),
      ),
    );
    final cellFinder = find.byKey(ValueKey('Cell'));

    expect(
      tester.getRect(cellFinder),
      Rect.fromLTWH(0.0, 0.0, 720, 60.0),
    );
  });

  testWidgets('Cell with relative extent', (WidgetTester tester) async {
    await tester.pumpWidget(
      RootWidget(
        width: 720, // 12 col x 60 width
        child: LayoutGrid(
          children: [
            Cell.relativeExtent(
              snap: 12,
              key: ValueKey('Cell'),
              relativeExtent: 1,
              child: Container(),
            )
          ],
        ),
      ),
    );
    final cellFinder = find.byKey(ValueKey('Cell'));

    expect(
      tester.getRect(cellFinder),
      Rect.fromLTWH(0.0, 0.0, 720, 60.0),
    );
  });
}
