import 'package:flutter_test/flutter_test.dart';
import 'package:layout_grid/layout_grid.dart';
import 'package:layout_grid/src/rendering/sliver_geometry.dart';

void main() {
  group('Test Cell Data', () {
    final LayoutGridConfiguration configuration = LayoutGridConfiguration(
      rails: 12,
      railExtent: 100,
      mainAxisSpacing: 0,
      crossAxisSpacing: 0,
      reverseCrossAxis: false,
      masonry: false,
    );

    test('CellData.extent - Main extent', () async {
      final data = CellData.extent(12, 100);
      final mainAxisExtent = configuration.mainAxisExtentFor(data);
      expect(data.mainAxisExtent, equals(100));
      expect(mainAxisExtent, equals(100));
    });

    test('CellData.fit - Main extent is Null', () async {
      final data = CellData.fit(12);
      final mainAxisExtent = configuration.mainAxisExtentFor(data);
      expect(data.mainAxisExtent, isNull);
      expect(mainAxisExtent, isNull);
    });

    test('CellData.count - Main extent for count 1', () async {
      final data = CellData.count(12, 1);
      final mainAxisExtent = configuration.mainAxisExtentFor(data);
      expect(data.mainAxisExtent, isNull);
      expect(mainAxisExtent, equals(1 * configuration.railExtent));
    });

    test('CellData.count - Main extent for count more than 1', () async {
      final data = CellData.count(12, 2);
      final mainAxisExtent = configuration.mainAxisExtentFor(data);
      expect(data.mainAxisExtent, isNull);
      expect(
        mainAxisExtent,
        equals(
          2 * configuration.crossAxisStride - configuration.crossAxisSpacing,
        ),
      );
    });

    test('CellData - Cross extent for 1 rail', () async {
      final data = CellData.fit(1);
      final crossAxisExtent = configuration.crossAxisExtentFor(data);
      expect(crossAxisExtent, equals(configuration.railExtent));
    });

    test('CellData - Cross extent for more than 1 rail', () async {
      final data = CellData.fit(2);
      final crossAxisExtent = configuration.crossAxisExtentFor(data);
      expect(
          crossAxisExtent,
          equals(2 * configuration.crossAxisStride -
              configuration.crossAxisSpacing));
    });
  });
}
